@@ -960,6 +960,9 @@ _g_path_remove_extension (const gchar *path)
 {
 	const char *ext;
 
+	if (path == NULL)
+		return NULL;
+
 	ext = _g_filename_get_extension (path);
 	if (ext == NULL)
 		return g_strdup (path);
@@ -968,6 +971,22 @@ _g_path_remove_extension (const gchar *path)
 }
 
 
+char *
+_g_path_remove_first_extension (const gchar *path)
+{
+	const char *ext;
+
+	if (path == NULL)
+		return NULL;
+
+	ext = strrchr (path, '.');
+	if (ext == NULL)
+		return g_strdup (path);
+	else
+		return g_strndup (path, strlen (path) - strlen (ext));
+}
+
+
 /* Check whether the dirname is contained in filename */
 gboolean
 _g_path_is_parent_of (const char *dirname,
